package com.xinelu.manage.service.patientquestionoptionresult;

import com.xinelu.manage.domain.patientquestionoptionresult.PatientQuestionOptionResult;

import java.util.List;

/**
 * 患者问卷题目选项提交结果信息Service接口
 *
 * @author xinelu
 * @date 2024-03-28
 */
public interface IPatientQuestionOptionResultService {
    /**
     * 查询患者问卷题目选项提交结果信息
     *
     * @param id 患者问卷题目选项提交结果信息主键
     * @return 患者问卷题目选项提交结果信息
     */
    PatientQuestionOptionResult selectPatientQuestionOptionResultById(Long id);

    /**
     * 查询患者问卷题目选项提交结果信息列表
     *
     * @param patientQuestionOptionResult 患者问卷题目选项提交结果信息
     * @return 患者问卷题目选项提交结果信息集合
     */
    List<PatientQuestionOptionResult> selectPatientQuestionOptionResultList(PatientQuestionOptionResult patientQuestionOptionResult);

    /**
     * 新增患者问卷题目选项提交结果信息
     *
     * @param patientQuestionOptionResult 患者问卷题目选项提交结果信息
     * @return 结果
     */
    int insertPatientQuestionOptionResult(PatientQuestionOptionResult patientQuestionOptionResult);

    /**
     * 修改患者问卷题目选项提交结果信息
     *
     * @param patientQuestionOptionResult 患者问卷题目选项提交结果信息
     * @return 结果
     */
    int updatePatientQuestionOptionResult(PatientQuestionOptionResult patientQuestionOptionResult);

    /**
     * 批量删除患者问卷题目选项提交结果信息
     *
     * @param ids 需要删除的患者问卷题目选项提交结果信息主键集合
     * @return 结果
     */
    int deletePatientQuestionOptionResultByIds(Long[] ids);

    /**
     * 删除患者问卷题目选项提交结果信息信息
     *
     * @param id 患者问卷题目选项提交结果信息主键
     * @return 结果
     */
    int deletePatientQuestionOptionResultById(Long id);
}
